describe('Spies', function () {

    it ("should create an anonymous spy", function () {
        var spy = sinon.spy();

        spy('Hello World');

        expect(spy.callCount).toEqual(1);
        expect(spy.calledWith('Hello World')).toBeTruthy();
    });

    it("should create a spy for a method", function () {
        var myObj = {
            name: 'Klaus',
            getName: function () {
                return this.name;
            }
        };

        var spy = sinon.spy(myObj, 'getName');

        myObj.getName();

        expect(spy.calledOnce).toBeTruthy();

        myObj.getName.restore();
    });

});


describe('EventEmitter', function () {

    it ('should register a callback via on-method', function () {
        var eventEmitter = new EventEmitter();

        eventEmitter.on('myEvent', function () {});

        expect(eventEmitter.events['myEvent'].length).toBe(1);
    });

    it('should fire an event, if the trigger method is called', function () {
        var eventEmitter = new EventEmitter();
        var spy = sinon.spy();
        eventEmitter.events['myEvent'] = [spy];

        eventEmitter.trigger('myEvent');

        expect(spy.calledOnce).toBeTruthy();
    });

    it('call all the registered callbacks', function () {
        var eventEmitter = new EventEmitter();
        var spy = sinon.spy();
        eventEmitter.events['myEvent'] = [spy, spy];

        eventEmitter.trigger('myEvent');

        expect(spy.calledTwice).toBeTruthy();
    });

    it('should pass args to the callback', function () {
        var eventEmitter = new EventEmitter();
        var spy = sinon.spy();
        eventEmitter.events['myEvent'] = [spy];

        eventEmitter.trigger('myEvent', 'arg1');

        expect(spy.calledWith('arg1')).toBeTruthy();
    });

    it('should work with jasmine as well', function () {
        var myObj = {
            cb: function () {}
        }

        var eventEmitter = new EventEmitter();
        spyOn(myObj, 'cb');
        eventEmitter.events['myEvent'] = [myObj.cb];

        eventEmitter.trigger('myEvent');

        expect(myObj.cb).toHaveBeenCalled();
    });

    it('should work', function () {

        var lala = {

            name: 'huhu',
            setName: function (name) {
                this.name = name;
            }

        };

        spyOn(lala, 'setName').andCallThrough();

        lala.setName('Klaus');

        expect(lala.setName).toHaveBeenCalledWith('Klaus');
        expect(lala.name).toBe('Klaus');
    });

});
