describe('Stubs', function () {
    it('should create a stub', function () {
        var myObj = {
            name: 'Klaus',
            getName: function () {
                return this.name;
            }
        }

        var stub1 = sinon.stub();
        var stub2 = sinon.stub(myObj, 'getName');
        var stub3 = sinon.stub(myObj);
    });
    it('should return and throw', function () {
        var myObj = {
            getName: function () {},
            setName: function () {}
        }

        var stub1 = sinon.stub(myObj, 'getName').returns('Klaus');
        var stub2 = sinon.stub(myObj, 'setName').throws(new Error('You are not allowed to do this'));

        expect(stub1()).toBe('Klaus');
    });

    it('should work withArgs', function () {
        var stub = sinon.stub();

        stub.withArgs(1).returns('Klaus');
        stub.withArgs(2).returns('Hans');

        expect(stub(1)).toBe('Klaus');
        expect(stub(2)).toBe('Hans');
    });
});

describe('Password', function () {
    it ("should generate a password with 7 characters", function () {
        var password = generatePassword(7, Math.random);
        expect(password.length).toBe(7);
    });

    it ("should generate a random password", function () {
        sinon.stub(Math, 'random').returns(0.5390104921534657);

        var password = generatePassword(7, Math.random);

        expect(password).toBe('ccccccc');
    });
});

describe('Jasmine', function () {
    it ('should also support stubs', function () {
        var myObj = {
            getName: function () {}
        }

        spyOn(myObj, 'getName').andReturn('Klaus');

        expect(myObj.getName()).toBe('Klaus');
    });
});
